# GPT4Free
- [GPT4Free](https://github.com/xtekky/gpt4free)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Disclaimer
We do not know where your data goes when you use GPT4Free. We do not know if it is stored or sold. It is not recommended to use this provider for sensitive data. This was developed for experimental purposes and we assume no responsibility for how you use it.

## Quick Start Guide
### Update your agent settings
1. Set `AI_PROVIDER` to `gpt4free`
2. Set `AI_MODEL` to `gpt-4` or `gpt-3.5-turbo`.
3. Set `AI_TEMPERATURE` to a value between 0 and 1. The higher the value, the more creative the output.
4. Set `MAX_TOKENS` to the maximum number of tokens to generate. The higher the value, the longer the output.